[PATCH 3/8] Drivers:MTD:Nand: remove the redefinition error

venkat.prashanth2498 at gmail.com venkat.prashanth2498 at gmail.com
Thu Dec 14 19:57:09 PST 2017


From: Venkat Prashanth B U <venkat.prashanth2498 at gmail.com>

This is a patch to the omap_elm.c file which fixes the redefinition
error in the function‘elm_decode_bch_error_page’

Signed-off-by: Venkat Prashanth B U <venkat.prashanth2498 at gmail.com>
---
 drivers/mtd/nand/omap_elm.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/mtd/nand/omap_elm.c b/drivers/mtd/nand/omap_elm.c
index 235ec79..06c24f3 100644
--- a/drivers/mtd/nand/omap_elm.c
+++ b/drivers/mtd/nand/omap_elm.c
@@ -335,7 +335,7 @@ static void elm_error_correction(struct elm_info *info,
 }

 /**
  * elm_decode_bch_error_page - Locate error position
  * @dev:	device pointer
  * @ecc_calc:	calculated ECC bytes from GPMC
  * @err_vec:	elm error vectors
@@ -343,7 +343,7 @@ static void elm_error_correction(struct elm_info *info,
  * Called with one or more error reported vectors & vectors with
  * error reported is updated in err_vec[].error_reported
  */
-void elm_decode_bch_error_page(struct device *dev, u8 *ecc_calc,
+void elm_decode_bch_err_pg(struct device *dev, u8 *ecc_calc,
 		struct elm_errorvec *err_vec)
 {
 	struct elm_info *info = dev_get_drvdata(dev);
@@ -368,7 +368,7 @@ void elm_decode_bch_error_page(struct device *dev, u8 *ecc_calc,
 	elm_write_reg(info, ELM_IRQENABLE, reg_val & ~INTR_EN_PAGE_MASK);
 	elm_error_correction(info, err_vec);
 }
-EXPORT_SYMBOL(elm_decode_bch_error_page);
+EXPORT_SYMBOL(elm_decode_bch_err_pg);

 static irqreturn_t elm_isr(int this_irq, void *dev_id)
 {
@@ -335,7 +335,7 @@ static void elm_error_correction(struct elm_info *info,

 /**
- * elm_decode_bch_error_page - Locate error position
+ * elm_decode_bch_err_pg - Locate error position
  * @dev:	device pointer
  * @ecc_calc:	calculated ECC bytes from GPMC
--
1.9.1




More information about the linux-mtd mailing list